#include <stddef.h>
static const char *feature_flags[] __attribute__((__unused__)) = {
"dbus-config",
"generate-just-in-time",
"generated-supplicant",
"auth-phase2",
"dhcp-use-domains",
"ipv6-mtu",
"modems",
"sriov",
"openvswitch",
NULL, };
